<?php $TRANSLATIONS = array(
"Contacts" => "Kontakter",
"Ok" => "OK",
"Cancel" => "Ofbriechen",
"Save" => "Späicheren",
"Edit Addressbook" => "Adressbuch editéieren",
"Error." => "Fehler.",
"Add group..." => "Grupp bäisetzen...",
"Select photo" => "Foto auswielen",
"Add group" => "Grupp bäisetzen",
"OK" => "OK",
"# groups" => "# Gruppen",
"Add" => "Dobäisetzen",
"All" => "All",
"Favorites" => "Favoriten",
"Import" => "Importeieren",
"Importing..." => "Gett importéiert...",
"Close" => "Zoumaachen",
"Unknown error" => "Et ass en onbekannte Fehler opgetrueden",
"{name}'s Birthday" => "{name} säi Gebuertsdag",
"Information about vCard is incorrect. Please reload the page." => "Informatioun iwwert vCard ass net richteg. Lued d'Säit wegl nei.",
"No photo path was submitted." => "Et gouf kee Foto-Pfad iwwerdroen.",
"Error getting PHOTO property." => "Feeler beim Luede vun der PHOTO-Eegeschaft.",
"Error saving contact." => "Feeler beim Späichere vum Kontakt.",
"There is no error, the file uploaded with success" => "Keen Feeler, Datei ass komplett ropgelueden ginn",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "Déi ropgelueden Datei ass méi grouss wei d'upload_max_filesize Eegenschaft an der php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Déi ropgelueden Datei ass méi grouss wei d'MAX_FILE_SIZE Eegenschaft déi an der HTML form uginn ass",
"The uploaded file was only partially uploaded" => "Déi ropgelueden Datei ass nëmmen hallef ropgelueden ginn",
"No file was uploaded" => "Et ass kee Fichier ropgeluede ginn",
"Missing a temporary folder" => "Et feelt en temporären Dossier",
"Failed to write to disk" => "Konnt net op den Disk schreiwen",
"Contact" => "Kontakt",
"Other" => "Aner",
"Jabber" => "Jabber",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "GoogleTalk",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"ownCloud" => "ownCloud",
"Work" => "Aarbecht",
"Home" => "Doheem",
"Mobile" => "GSM",
"Text" => "SMS",
"Voice" => "Voice",
"Message" => "Message",
"Fax" => "Fax",
"Video" => "Video",
"Pager" => "Pager",
"Internet" => "Internet",
"Friends" => "Frënn",
"Family" => "Famill",
"Group name" => "Gruppe Numm",
"Delete" => "Läschen",
"Groups" => "Gruppen",
"Download" => "Download",
"Email" => "Email",
"Phone" => "Telefon",
"Address" => "Adress",
"Group" => "Grupp",
"Add new contact" => "Neie Kontakt bäisetzen",
"Name" => "Numm",
"First name" => "Virnumm",
"Additional names" => "Weider Nimm",
"Last name" => "Famillje Numm",
"Nickname" => "Spëtznumm",
"Title" => "Titel",
"Organization" => "Firma",
"Birthday" => "Gebuertsdaag",
"Instant Messaging" => "Instant Messaging",
"Note" => "Note",
"Web site" => "Web site",
"Enter phone number" => "Telefonsnummer aginn",
"View on map" => "Op da Kaart uweisen",
"City" => "Staat",
"Country" => "Land",
"Active" => "Aktiv",
"Share" => "Deelen",
"Export" => "Exporteieren",
"CardDAV link" => "CardDav Link",
"Edit" => "Editéieren",
"Description" => "Beschreiwung",
"Password" => "Passwuert"
);
